@@ -1,5 +1,6 @@
 # testing/__init__.py
-# Copyright (C) 2005-2014 the SQLAlchemy authors and contributors <see AUTHORS file>
+# Copyright (C) 2005-2014 the SQLAlchemy authors and contributors
+# <see AUTHORS file>
 #
 # This module is part of SQLAlchemy and is released under
 # the MIT License: http://www.opensource.org/licenses/mit-license.php
@@ -18,9 +19,9 @@ def against(*queries):
     return _against(config._current, *queries)
 
 from .assertions import emits_warning, emits_warning_on, uses_deprecated, \
-        eq_, ne_, is_, is_not_, startswith_, assert_raises, \
-        assert_raises_message, AssertsCompiledSQL, ComparesTables, \
-        AssertsExecutionResults, expect_deprecated
+    eq_, ne_, is_, is_not_, startswith_, assert_raises, \
+    assert_raises_message, AssertsCompiledSQL, ComparesTables, \
+    AssertsExecutionResults, expect_deprecated, expect_warnings
 
 from .util import run_as_contextmanager, rowset, fail, provide_metadata, adict
 
@@ -29,4 +30,4 @@ crashes = skip
 from .config import db
 from .config import requirements as requires
 
-from . import mock
\ No newline at end of file
+from . import mock
